execute method
Executes this configuration.
The context parameter provides access to the widget tree.
The optional arguments map contains parameters for the execution.
Implementation
@override
Future<void> execute(
flutter.BuildContext context, {
Map<String, dynamic>? arguments,
}) async {
final value = (await condition?.execute(context)) ?? defaultCase;
if (context.mounted) {
final caseAction = cases?.firstWhereOrNull(
(element) => element.value == value,
);
caseAction?.action?.execute(context);
}
}