CurrentPlatform class final

Inheritance
  • Object
  • ConditionConfiguration
  • CurrentPlatform

Constructors

CurrentPlatform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → String
The schema type of this configuration.
finalinherited
title → String?
Optional title for this configuration.
finalinherited

Methods

execute(BuildContext context) → Future<String?>
Evaluates this condition configuration.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

typeDescriptor → TypeDescriptor<CurrentPlatform>
final

Constants

schemaName → const String