build method
Builds the layout widget tree for the given content item.
This method is called by the content system to render the content item with the specified layout.
Implementation
@override
Widget build(BuildContext context, Divider content) {
final child = f.Divider(thickness: content.thickness);
return content.indent != null && content.indent! > 0
? Padding(padding: EdgeInsets.all(content.indent!), child: child)
: child;
}