theme method
ThemeData?
theme(
- ThemeMode mode
Gets the theme data for the specified theme mode. Returns null
if no theme data is configured for the specified mode.
Implementation
ThemeData? theme(ThemeMode mode) => _themeMap[mode];